Index: src/ia32/macro-assembler-ia32.cc |
diff --git a/src/ia32/macro-assembler-ia32.cc b/src/ia32/macro-assembler-ia32.cc |
index fa3be8ead154a6fa242780739c557f7328555525..cbf9efb11f4a21a5f63c35b26c0a64ad5dd84235 100644 |
--- a/src/ia32/macro-assembler-ia32.cc |
+++ b/src/ia32/macro-assembler-ia32.cc |
@@ -1069,7 +1069,10 @@ |
Check(not_equal, kWeShouldNotHaveAnEmptyLexicalContext); |
} |
// Load the native context of the current context. |
- mov(scratch1, ContextOperand(scratch1, Context::NATIVE_CONTEXT_INDEX)); |
+ int offset = |
+ Context::kHeaderSize + Context::GLOBAL_OBJECT_INDEX * kPointerSize; |
+ mov(scratch1, FieldOperand(scratch1, offset)); |
+ mov(scratch1, FieldOperand(scratch1, JSGlobalObject::kNativeContextOffset)); |
// Check the context is a native context. |
if (emit_debug_code()) { |
@@ -2128,7 +2131,8 @@ |
void MacroAssembler::GetBuiltinFunction(Register target, |
int native_context_index) { |
// Load the JavaScript builtin function from the builtins object. |
- mov(target, NativeContextOperand()); |
+ mov(target, GlobalObjectOperand()); |
+ mov(target, FieldOperand(target, JSGlobalObject::kNativeContextOffset)); |
mov(target, ContextOperand(target, native_context_index)); |
} |
@@ -2160,8 +2164,8 @@ |
void MacroAssembler::LoadGlobalProxy(Register dst) { |
- mov(dst, NativeContextOperand()); |
- mov(dst, ContextOperand(dst, Context::GLOBAL_PROXY_INDEX)); |
+ mov(dst, GlobalObjectOperand()); |
+ mov(dst, FieldOperand(dst, JSGlobalObject::kGlobalProxyOffset)); |
} |
@@ -2172,7 +2176,8 @@ |
Register scratch, |
Label* no_map_match) { |
// Load the global or builtins object from the current context. |
- mov(scratch, NativeContextOperand()); |
+ mov(scratch, Operand(esi, Context::SlotOffset(Context::GLOBAL_OBJECT_INDEX))); |
+ mov(scratch, FieldOperand(scratch, JSGlobalObject::kNativeContextOffset)); |
// Check that the function's map is the same as the expected cached map. |
mov(scratch, Operand(scratch, |
@@ -2191,10 +2196,13 @@ |
void MacroAssembler::LoadGlobalFunction(int index, Register function) { |
- // Load the native context from the current context. |
- mov(function, NativeContextOperand()); |
+ // Load the global or builtins object from the current context. |
+ mov(function, |
+ Operand(esi, Context::SlotOffset(Context::GLOBAL_OBJECT_INDEX))); |
+ // Load the native context from the global or builtins object. |
+ mov(function, FieldOperand(function, JSGlobalObject::kNativeContextOffset)); |
// Load the function from the native context. |
- mov(function, ContextOperand(function, index)); |
+ mov(function, Operand(function, Context::SlotOffset(index))); |
} |